@@ -110,7 +110,7 @@ polar <- function(seq, polarity=NULL) {
 
 #' Calculates the hydrophobicity of amino acid sequences
 #'
-#' \code{gravy} calculates the Grand Average of Hydrophobicity (GRAVY) index 
+#' \code{gravy} calculates the Grand Average of Hydrophobicity (gravy) index 
 #' of amino acid sequences using the method of Kyte & Doolittle. Non-informative
 #' positions are excluded, where non-informative is defined as any character in 
 #' \code{c("X", "-", ".", "*")}.
@@ -121,7 +121,7 @@ polar <- function(seq, polarity=NULL) {
 #'                       character codes. If \code{NULL}, then the Kyte & Doolittle
 #'                       scale is used.
 #' 
-#' @return   A vector of GRAVY scores for the sequence(s).
+#' @return   A vector of gravy scores for the sequence(s).
 #' 
 #' @references
 #' \enumerate{
@@ -156,7 +156,7 @@ gravy <- function(seq, hydropathy=NULL) {
     seq <- gsub("[X\\.\\*-]", "", as.character(seq))
     # Create character vector from string
     aa <- strsplit(seq, "")
-    # Calculate GRAVY
+    # Calculate gravy
     aa_gravy <- sapply(aa, function(x) sum(hydropathy[x]) / length(x))
     
     return(aa_gravy)
@@ -353,15 +353,14 @@ countOccurrences <- function(x, pattern) {
 #'          "TGTCAGCAATATTATATTGCTCCCTTCACTTTC",
 #'          "TGTCAAAAGTATAACAGTGCCCCCTGGACGTTC")
 #' patterns <- c("A", "V", "[LI]")
-#' names(patterns) <- c("ARG", "VAL", "ISO_LEU")
-#' countPatterns(seq, patterns, nt=TRUE, trim=TRUE, label="CDR3")
+#' names(patterns) <- c("arg", "val", "iso_leu")
+#' countPatterns(seq, patterns, trim=TRUE, label="cdr3")
 #'             
 #' @export
-countPatterns <- function(seq, patterns, nt=FALSE, trim=FALSE, label="REGION") {
+countPatterns <- function(seq, patterns, nt=TRUE, trim=FALSE, label="region") {
     # Translate sequences if nucleotide
     region_aa <- if (nt) { translateDNA(seq, trim=trim) } else { seq }
     
-    # TODO: Check that NA is passed through correctly.
     # TODO: What is the proper length normalization? With or without non-informative position?
     
     # Calculate region lengths
@@ -405,17 +404,17 @@ countPatterns <- function(seq, patterns, nt=FALSE, trim=FALSE, label="REGION") {
 #' 
 #' @return  A modified \code{data} data.frame with the following columns:
 #'          \itemize{
-#'            \item  \code{*_AA_LENGTH}:     number of amino acids.
-#'            \item  \code{*_AA_GRAVY}:      grand average of hydrophobicity (GRAVY) index.
-#'            \item  \code{*_AA_BULK}:       average bulkiness of amino acids.
-#'            \item  \code{*_AA_ALIPHATIC}:  aliphatic index.
-#'            \item  \code{*_AA_POLARITY}:   average polarity of amino acids.
-#'            \item  \code{*_AA_CHARGE}:     net charge.
-#'            \item  \code{*_AA_BASIC}:      fraction of informative positions that are 
+#'            \item  \code{*_aa_length}:     number of amino acids.
+#'            \item  \code{*_aa_gravy}:      grand average of hydrophobicity (gravy) index.
+#'            \item  \code{*_aa_bulk}:       average bulkiness of amino acids.
+#'            \item  \code{*_aa_aliphatic}:  aliphatic index.
+#'            \item  \code{*_aa_polarity}:   average polarity of amino acids.
+#'            \item  \code{*_aa_charge}:     net charge.
+#'            \item  \code{*_aa_basic}:      fraction of informative positions that are 
 #'                                           Arg, His or Lys.
-#'            \item  \code{*_AA_ACIDIC}:     fraction of informative positions that are 
+#'            \item  \code{*_aa_acidic}:     fraction of informative positions that are 
 #'                                           Asp or Glu.
-#'            \item  \code{*_AA_AROMATIC}:   fraction of informative positions that are 
+#'            \item  \code{*_aa_aromatic}:   fraction of informative positions that are 
 #'                                           His, Phe, Trp or Tyr.
 #'            
 #'          }
@@ -427,7 +426,7 @@ countPatterns <- function(seq, patterns, nt=FALSE, trim=FALSE, label="REGION") {
 #' For all properties except for length, non-informative positions are excluded, 
 #' where non-informative is defined as any character in \code{c("X", "-", ".", "*")}.
 #' 
-#' The scores for GRAVY, bulkiness and polarity are calculated as simple averages of the 
+#' The scores for gravy, bulkiness and polarity are calculated as simple averages of the 
 #' scores for each informative positions. The basic, acid and aromatic indices are 
 #' calculated as the fraction of informative positions falling into the given category.
 #' 
@@ -473,15 +472,15 @@ countPatterns <- function(seq, patterns, nt=FALSE, trim=FALSE, label="REGION") {
 #' 
 #' @examples
 #' # Subset example data
-#' db <- ExampleDb[c(1,10,100), c("SEQUENCE_ID", "JUNCTION")]
+#' db <- ExampleDb[c(1,10,100), c("sequence_id", "junction")]
 #' 
+#' # Calculate default amino acid properties from DNA sequences
+#' aminoAcidProperties(db, seq="junction")
+#
 #' # Calculate default amino acid properties from amino acid sequences
 #' # Use a custom output column prefix
-#' db$JUNCTION_TRANS <- translateDNA(db$JUNCTION)
-#' aminoAcidProperties(db, seq="JUNCTION_TRANS", label="JUNCTION")
-#
-#' # Calculate default amino acid properties from DNA sequences
-#' aminoAcidProperties(db, seq="JUNCTION", nt=TRUE)
+#' db$junction_aa <- translateDNA(db$junction)
+#' aminoAcidProperties(db, seq="junction_aa", label="junction", nt=FALSE)
 #' 
 #' # Use the Grantham, 1974 side chain volume scores from the seqinr package
 #' # Set pH=7.0 for the charge calculation
@@ -493,28 +492,28 @@ countPatterns <- function(seq, patterns, nt=FALSE, trim=FALSE, label="REGION") {
 #' # Rename the score vector to use single-letter codes
 #' names(x) <- translateStrings(names(x), ABBREV_AA)
 #' # Calculate properties
-#' aminoAcidProperties(db, property=c("bulk", "charge"), seq="JUNCTION", nt=TRUE, 
-#'                     trim=TRUE, label="CDR3", bulkiness=x, pH=7.0)
+#' aminoAcidProperties(db, property=c("bulk", "charge"), seq="junction", 
+#'                     trim=TRUE, label="cdr3", bulkiness=x, pH=7.0)
 #'
 #' @export
 aminoAcidProperties <- function(data, property=c("length", "gravy", "bulk",
                                                  "aliphatic","polarity","charge",
                                                  "basic","acidic", "aromatic"),
-                                seq="JUNCTION", nt=FALSE, trim=FALSE, label=NULL, ...) {
+                                seq="junction", nt=TRUE, trim=FALSE, label=NULL, ...) {
     # Check arguments
     property <- match.arg(property, several.ok=TRUE)
     
     # Define the data.frame that will be returned with amino acid properties
     prop_colnames <- list(
-        "length"    = "AA_LENGTH",
-        "gravy"     = "AA_GRAVY",
-        "bulk"      = "AA_BULK",
-        "aliphatic" = "AA_ALIPHATIC",
-        "polarity"  = "AA_POLARITY",
-        "charge"    = "AA_CHARGE",
-        "basic"     = "AA_BASIC",
-        "acidic"    = "AA_ACIDIC",
-        "aromatic"  = "AA_AROMATIC"
+        "length"    = "aa_length",
+        "gravy"     = "aa_gravy",
+        "bulk"      = "aa_bulk",
+        "aliphatic" = "aa_aliphatic",
+        "polarity"  = "aa_polarity",
+        "charge"    = "aa_charge",
+        "basic"     = "aa_basic",
+        "acidic"    = "aa_acidic",
+        "aromatic"  = "aa_aromatic"
     )
     # If no label, use sequence column name
     if (is.null(label)) { label <- seq }
@@ -592,7 +591,7 @@ aminoAcidProperties <- function(data, property=c("length", "gravy", "bulk",
     }
     
     # Count of informative positions
-    aa_info <-  stri_length(gsub("[X\\.\\*-]", "", region_aa))
+    aa_info <- stri_length(gsub("[X\\.\\*-]", "", region_aa))
     # Fraction of amino acid that are basic
     if ("basic" %in% property) {
         aa_basic <- countOccurrences(region_aa, "[RHK]") / aa_info
@@ -612,4 +611,3 @@ aminoAcidProperties <- function(data, property=c("length", "gravy", "bulk",
     data_cols <- colnames(data) %in% colnames(out_df) == FALSE
     return(cbind(data[, data_cols], out_df))
 }
-
