@@ -125,6 +125,7 @@ writeChangeoDb <- function(data, file) {
 #' @export
 makeTempDir <- function(prefix) {
     temp_path <- tempfile(paste0(prefix, "-temp-"))
+
     dir.create(temp_path)
     
     return(temp_path)
@@ -276,34 +277,35 @@ baseTheme <- function(sizing=c("figure", "window")) {
     # Check arguments
     sizing <- match.arg(sizing)
     
+    base_theme <- theme_bw() +
+        theme(strip.background=element_blank(),
+              plot.background=element_blank(),
+              panel.grid.major=element_blank(), 
+              panel.grid.minor=element_blank())
+              
     # Define universal plot settings appropriate for PDF figures
     if (sizing == "figure") {
-        base_theme <- theme_bw() + 
-            theme(text=element_text(size=8)) +
-            theme(plot.title=element_text(size=8)) +
-            theme(plot.background=element_blank(),
-                  panel.grid.major=element_blank(), 
-                  panel.grid.minor=element_blank()) +
-            theme(strip.background=element_blank(),
-                  strip.text=element_text(size=7, face='bold')) +
-            theme(axis.title=element_text(size=8, vjust=0.25),
+        base_theme <- base_theme + 
+            theme(text=element_text(size=8),
+                  plot.title=element_text(size=8),
+                  strip.text=element_text(size=7, face="bold"),
+                  axis.title=element_text(size=8, vjust=0.25),
                   axis.text.x=element_text(size=8, vjust=0.5, hjust=0.5),
-                  axis.text.y=element_text(size=8)) +
-            theme(legend.text=element_text(size=7),
+                  axis.text.y=element_text(size=8),
+                  legend.text=element_text(size=7),
                   legend.title=element_text(size=7),
                   legend.key.height=grid::unit(10, "points"), 
                   legend.key.width=grid::unit(10, "points"))
     } else if (sizing == "window") {
         # Define universal plot settings appropriate for an interactive session
-        base_theme <- theme_bw() + 
-            theme(text=element_text(size=14)) +
-            theme(plot.title=element_text(size=16)) +
-            theme(strip.background=element_rect(fill='white'), 
-                  strip.text=element_text(size=14, face='bold')) +
-            theme(axis.title=element_text(size=16, vjust=0.25),
+        base_theme <- base_theme + 
+            theme(text=element_text(size=14),
+                  plot.title=element_text(size=16),
+                  strip.text=element_text(size=14, face="bold"),
+                  axis.title=element_text(size=16, vjust=0.25),
                   axis.text.x=element_text(size=16, vjust=0.5, hjust=0.5),
-                  axis.text.y=element_text(size=16)) +
-            theme(legend.text=element_text(size=14),
+                  axis.text.y=element_text(size=16),
+                  legend.text=element_text(size=14),
                   legend.title=element_text(size=14),
                   legend.key.height=grid::unit(18, "points"), 
                   legend.key.width=grid::unit(18, "points"))
@@ -366,6 +368,9 @@ cpuCount <-function(){
     } else {
         nproc <- 1    
     }
+	
+	# in case an NA is returned
+	if(is.na(nproc)){nproc <- 1}
     
     return(nproc)
 }
@@ -409,14 +414,22 @@ stoufferMeta <- function(p, w=NULL) {
     return(c(Z=Z, pvalue=pvalue))
 }
 
+
 # Stirling's approximation of the binomial coefficient
 # 
-# Calculates Stirling's approximation of the binomial coefficient for large numbers.
-#
-# @param    n  a vector of n.
-# @param    k  a vector of k.
+# \code{lchooseStirling} calculates Stirling's approximation of the binomial coefficient 
+# for large numbers.
 #
+# @param    n  vector of n.
+# @param    k  vector of k.
 # @return   The approximation of log(n choose k). For n < 100 \link{lchoose} is used.
+#
+# @seealso  \link{lchoose}.
+#
+# @examples
+# alakazam:::lchooseStirling(10e9, 10e4)
+#
+# @export
 lchooseStirling <- function(n, k) {
     if (any(n < k)) {
         stop("n must be >= k")
@@ -453,7 +466,6 @@ lchooseStirling <- function(n, k) {
         stop("Inputs are wrong. n and k must have the same length or be length one.")
     } 
     
-    
     # Small n
     nCk[x] <-  lchoose(n[a], k[i])
     
